Copyable

Trait Copyable 

pub unsafe trait Copyable: Copy { }
Marker trait for copyable types.

Safety

Implement this trait only for types that may safely be cast and read as a series of bytes. That means the type must not have any internal padding.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors